Welcome to anyvc's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   workdir/index.rst
   roadmap.rst
   about.rst

Anyvc is supposed to abstract differences betwen various VCS's.




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

